# InlineResponse200

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | A user ID | [optional] 
**email** | **str** | The email address of the token&#x27;s owner | [optional] 
**scopes** | **list[str]** | The scopes the token has. Only returned if accessing via an OAuth access token | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

